@@ -1,4 +1,6 @@
 from .bind import bind_method
+from .deprecations import deprecated
+from .encoder import ParameterEncoder
 from .request import OAuth2API
 
 SUPPORTED_FORMATS = ['json', 'object']
@@ -9,7 +11,7 @@ class MonitoringAPI(OAuth2API):
     Monitoring API object.
 
     This class represents an API object where users can fetch any kind of
-    monitoring data type. In order to grant the request, api_key or access_token
+    monitoring data. In order to grant the request, `api_key` or `access_token`
     field must be provided when creating an instance.
     """
 
@@ -27,8 +29,10 @@ class MonitoringAPI(OAuth2API):
         if response_format in SUPPORTED_FORMATS:
             self.format = response_format
         else:
-            raise Exception('Unsupported format')
+            raise Exception('Unsupported response format. '
+                            'Valid formats are: {}.'.format(SUPPORTED_FORMATS))
         self.api_key = kwargs.get('api_key')
+        self.encoder_class = kwargs.get('encoder_class', ParameterEncoder)
         super(MonitoringAPI, self).__init__(**kwargs)
 
     def get_fetch_method(self, name):
@@ -36,7 +40,12 @@ class MonitoringAPI(OAuth2API):
         method_name = 'fetch_{}'.format(name)
         return getattr(self, method_name, None)
 
-    fetch_doas = bind_method(path='doas/')
+    fetch_doas = deprecated(
+        '0.10.0',
+        'fetch_doas method is deprecated. Use fetch_doas2 method instead. '
+        'See more information at: '
+        'https://bma.cendana15.com/docs/apis/monitoring/doas.html',
+    )(bind_method(path='doas/'))
 
     fetch_gas_emission = bind_method(path='gas/emission/')
 
@@ -70,7 +79,13 @@ class MonitoringAPI(OAuth2API):
         path='rsam/infrasound/{station}/{band}/',
         accepts_parameters=['station', 'band'])
 
-    fetch_thermal = bind_method(path='thermal/')
+    fetch_thermal = deprecated(
+        '0.10.0',
+        'fetch_thermal method is deprecated. '
+        'Use fetch_thermal2 method instead. '
+        'See more information at: '
+        'https://bma.cendana15.com/docs/apis/monitoring/thermal.html',
+    )(bind_method(path='thermal/'))
 
     fetch_thermal2 = bind_method(path='thermal2/')
 
@@ -127,3 +142,8 @@ class MonitoringAPI(OAuth2API):
     fetch_windrose = bind_method(path='meteorology/windrose/')
 
     fetch_rainfall = bind_method(path='meteorology/rainfall/')
+
+    fetch_topo = bind_method(path='topo/')
+
+    fetch_doas2 = bind_method(path='doas2/{station}/',
+                              accepts_parameters=['station'])
